import sys
import json

from testwizard.commands_core import CommandBase
from .GetVideoFormatResult import GetVideoFormatResult


class GetVideoFormatCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "GetVideoFormat")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return GetVideoFormatResult(result, "GetVideoFormat was successful", "GetVideoFormat failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class FilterInvertCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FilterInvert")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return FilterResult(result, "FilterInvert was successful", "FilterInvert failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class DetectMotionResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(
            self, result["time"] >= 0 and result["errorCode"] == 0, successMessage, failMessage)

        self.time = result["time"]
        self.difference = result["difference"]
        self.distance = result["distance"]

        if self.success is True:
            return

        if result["errorCode"] == 14:
            self.message = self.message + ": motionDuration is bigger than Timeout"
        else:
            self.message = self.getMessageForErrorCode(self.message, result["errorCode"])



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class GetVideoFormatResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        self.videoFormat = result["format"]

        ResultBase.__init__(self, self.videoFormat >= 0, successMessage, failMessage)



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class GetVideoResolutionResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        self.width = result["width"]
        self.height = result["height"]

        ResultBase.__init__(self, self.width != -1 and self.height != -1, successMessage, failMessage)



from .CaptureReferenceBitmapCommand import CaptureReferenceBitmapCommand
from .CompareCommand import CompareCommand
from .CountLastPatternMatchesCommand import CountLastPatternMatchesCommand
from .DeleteAllRecordingsCommand import DeleteAllRecordingsCommand
from .DeleteAllSnapshotsCommand import DeleteAllSnapshotsCommand
from .DetectMotionCommand import DetectMotionCommand
from .DetectNoMotionCommand import DetectNoMotionCommand
from .FilterBlackWhiteCommand import FilterBlackWhiteCommand
from .FilterCBICommand import FilterCBICommand
from .FilterColorBlackWhiteCommand import FilterColorBlackWhiteCommand
from .FilterGrayscaleCommand import FilterGrayscaleCommand
from .FilterInvertCommand import FilterInvertCommand
from .FindAllPatternLocationsCommand import FindAllPatternLocationsCommand
from .FindAllPatternLocationsExCommand import FindAllPatternLocationsExCommand
from .FindPatternCommand import FindPatternCommand
from .FindPatternExCommand import FindPatternExCommand
from .GetVideoFormatCommand import GetVideoFormatCommand
from .GetVideoResolutionCommand import GetVideoResolutionCommand
from .LoadReferenceBitmapCommand import LoadReferenceBitmapCommand
from .SaveReferenceBitmapCommand import SaveReferenceBitmapCommand
from .SaveRegionCommand import SaveRegionCommand
from .SetRegionCommand import SetRegionCommand
from .SnapShotBMPCommand import SnapShotBMPCommand
from .SnapShotJPGCommand import SnapShotJPGCommand
from .StartBackgroundCaptureCommand import StartBackgroundCaptureCommand
from .StartRecordingCommand import StartRecordingCommand
from .StopBackgroundCaptureCommand import StopBackgroundCaptureCommand
from .StopRecordingCommand import StopRecordingCommand
from .TextOCRCommand import TextOCRCommand
from .WaitForColorCommand import WaitForColorCommand
from .WaitForColorNoMatchCommand import WaitForColorNoMatchCommand
from .WaitForPatternCommand import WaitForPatternCommand
from .WaitForPatternNoMatchCommand import WaitForPatternNoMatchCommand
from .WaitForSampleCommand import WaitForSampleCommand
from .WaitForSampleNoMatchCommand import WaitForSampleNoMatchCommand


import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class FilterGrayscaleCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FilterGrayscale")

    def execute(self, levels):
        if levels is None:
            raise Exception("levels is required")

        requestObj = [levels]

        result = self.executeCommand(requestObj, "Could not execute command")

        return FilterResult(result, "FilterGrayscale was successful", "FilterGrayscale failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkResult import OkResult


class StopRecordingCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "StopRecording")

    def execute(self):
        requestObj = []

        result = self.executeCommand(requestObj, "Could not execute command")

        return OkResult(result, "StopRecording was successful", "StopRecording failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class FilterCBICommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FilterCBI")

    def execute(self, contrast, brightness, intensity):
        if contrast is None:
            raise Exception("contrast is required")
        if brightness is None:
            raise Exception("brightness is required")
        if intensity is None:
            raise Exception("intensity is required")

        requestObj = [contrast, brightness, intensity]

        result = self.executeCommand(requestObj, "Could not execute command")

        return FilterResult(result, "FilterCBI was successful", "FilterCBI failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase


class FindPatternResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        self.similarity = result["similarity"]
        self.position = result["position"]

        ResultBase.__init__(self, self.similarity != -1 and result["errorCode"] == 0, successMessage, failMessage)

        if self.success is True:
            return

        self.message = self.getMessageForErrorCode(self.message, result["errorCode"])



import sys
import json

from testwizard.commands_core import CommandBase
from .SaveFileResult import SaveFileResult


class SnapShotJPGCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "SnapShotJPG")

    def execute(self, filename, quality):
        if filename is None:
            raise Exception("filename is required")
        if quality is None:
            raise Exception("quality is required")

        requestObj = [filename, quality]

        result = self.executeCommand(requestObj, "Could not execute command")

        return SaveFileResult(result, "SnapShotJPG was successful", "SnapShotJPG failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class FilterBlackWhiteCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FilterBlackWhite")

    def execute(self, separation):
        if separation is None:
            raise Exception("separation is required")

        requestObj = [separation]

        result = self.executeCommand(requestObj, "Could not execute command")

        return FilterResult(result, "FilterBlackWhite was successful", "FilterBlackWhite failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class SetRegionCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "SetRegion")

    def execute(self, x, y, width, height):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")

        requestObj = [x, y, width, height]

        result = self.executeCommand(requestObj, "Could not execute command")

        return FilterResult(result, "SetRegion was successful", "SetRegion failed")
